@@ -5,14 +5,14 @@ package Config::XrmDatabase;
 use v5.26;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Feature::Compat::Try;
 
 use Config::XrmDatabase::Failure ':all';
 use Config::XrmDatabase::Util ':all';
 use Config::XrmDatabase::Types -all;
-use Types::Standard qw( Object Str Optional );
+use Types::Standard qw( Object Str Optional HashRef );
 use Type::Params qw( compile_named );
 use Ref::Util;
 
@@ -46,6 +46,14 @@ has _query_on_failure => (
     default  => 'undef',
 );
 
+# fake attribute so we can use MooX::StrictConstructor
+has _insert => (
+    is        => 'ro',
+    isa       => HashRef,
+    init_arg  => 'insert',
+    predicate => 1,
+    clearer   => 1,
+);
 
 
 
@@ -73,6 +81,22 @@ has _query_on_failure => (
 
 
 
+
+
+
+
+
+
+
+
+
+sub BUILD ( $self, $ ) {
+    if ( $self->_has_insert ) {
+        my $kv = $self->_insert;
+        $self->insert( $_, $kv->{$_} ) for keys %$kv;
+        $self->_clear_insert;
+    }
+}
 
 
 
@@ -706,7 +730,7 @@ Config::XrmDatabase - Pure Perl X Resource Manager Database
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -846,6 +870,10 @@ C<on_failure> parameter.
 It defaults to the string C<undef>.
 See L</query> for more details.
 
+=item C<insert> I<hash>
+
+Populate the database with the supplied data.
+
 =back
 
 =head2 read_file
@@ -1072,6 +1100,8 @@ Convert the DB object into a hash.  Useful? Who knows?
 
 See L</to_kv> for a perhaps more useful output.
 
+=for Pod::Coverage BUILD
+
 =begin internals
 
 =method _to_kv_xx
